﻿using System.Globalization;
using System.Threading;
using System.Windows;
using Telerik.Windows.Controls;

namespace WpfApp
{
	/// <summary>
	/// Interaction logic for WindowIndex.xaml
	/// </summary>
	public partial class WindowIndex : Window
	{
		public static ChosenLocalizationManager localizationManager = ChosenLocalizationManager.None;

		public WindowIndex()
		{
			InitializeComponent();
			this.Loaded += new RoutedEventHandler(Page_Loaded);
		}

		void Page_Loaded(object sender, RoutedEventArgs e)
		{
			this.managerNone.IsChecked = (localizationManager == ChosenLocalizationManager.None);
			this.managerResourceDef.IsChecked = (localizationManager == ChosenLocalizationManager.ResourceDef);
			this.managerResourceEN.IsChecked = (localizationManager == ChosenLocalizationManager.ResourceEN);
			this.managerResourceDE.IsChecked = (localizationManager == ChosenLocalizationManager.ResourceDE);
			this.managerResourceJP.IsChecked = (localizationManager == ChosenLocalizationManager.ResourceJP);
			this.managerGetStringOverride.IsChecked = (localizationManager == ChosenLocalizationManager.GetStringOverride);
			this.InitializeLocalizationManager();
		}

		private void managerGroup_Click(object sender, RoutedEventArgs e)
		{
			this.InitializeLocalizationManager();
		}

		private void cultureGroup_Click(object sender, RoutedEventArgs e)
		{
			this.InitializeLocalizationManager();
		}

		private void InitializeLocalizationManager()
		{
			Thread.CurrentThread.CurrentUICulture = this.GetUICulture();
			LocalizationManager.Manager = this.GetLocalizationManager();
			this.openTestPage.Content = LocalizationManager.GetString("DemoBtnOpenTestPage")
				?? "Open test page";
		}

		private void openTestPage_Click(object sender, RoutedEventArgs e)
		{
			WindowIndex.localizationManager = this.GetLocalizationManagerType();
			(new WindowTestCombo()).ShowDialog();
		}

		internal LocalizationManager GetLocalizationManager()
		{
			LocalizationManager locMan = null;
			switch (this.GetLocalizationManagerType())
			{
				case ChosenLocalizationManager.ResourceDef:
					locMan = new LocalizationManager()
					{
						ResourceManager = WpfApp.Properties.Resources.ResourceManager,
						Culture = null
					};
					break;
				case ChosenLocalizationManager.ResourceDE:
					locMan = new LocalizationManager()
					{
						ResourceManager = WpfApp.Properties.Resources.ResourceManager,
						Culture = new CultureInfo("de")
					};
					break;
				case ChosenLocalizationManager.ResourceEN:
					locMan = new LocalizationManager()
					{
						ResourceManager = WpfApp.Properties.Resources.ResourceManager,
						Culture = new CultureInfo("en")
					};
					break;
				case ChosenLocalizationManager.ResourceJP:
					locMan = new LocalizationManager()
					{
						ResourceManager = WpfApp.Properties.Resources.ResourceManager,
						Culture = new CultureInfo("ja")
					};
					break;
				case ChosenLocalizationManager.GetStringOverride:
					locMan = new MyLocalizationManager();
					break;
			}
			return locMan;
		}

		internal CultureInfo GetUICulture()
		{
			return (this.cultureEN.IsChecked == true) ? new CultureInfo("en")
				: (this.cultureDE.IsChecked == true) ? new CultureInfo("de")
				: (this.cultureJp.IsChecked == true) ? new CultureInfo("ja")
				: Thread.CurrentThread.CurrentCulture;
		}

		internal ChosenLocalizationManager GetLocalizationManagerType()
		{
			return (this.managerResourceEN.IsChecked == true) ? ChosenLocalizationManager.ResourceEN
				: (this.managerResourceDE.IsChecked == true) ? ChosenLocalizationManager.ResourceDE
				: (this.managerResourceDef.IsChecked == true) ? ChosenLocalizationManager.ResourceDef
				: (this.managerResourceJP.IsChecked == true) ? ChosenLocalizationManager.ResourceJP
				: (this.managerGetStringOverride.IsChecked == true) ? ChosenLocalizationManager.GetStringOverride
				: ChosenLocalizationManager.None;
		}

		public enum ChosenLocalizationManager
		{
			None, ResourceDef, ResourceEN, ResourceDE, ResourceJP, GetStringOverride
		}
	}
}
